==> haitch-0.10.1.tar.gz: haitch-0.10.1/src/haitch/_elements/_form.py <==
from __future__ import annotations

from typing import Literal, Mapping, NewType

from typing_extensions import NotRequired, Unpack

from haitch._attrs import AttributeValue, GlobalAttrs
from haitch._elements._element import Element
from haitch._typing import Child

FormElement = NewType("FormElement", Element)
"""An `<form>` element."""


def form(
    *children: Child,
    extra_attrs: Mapping[str, AttributeValue] = {},
    **attrs: Unpack[FormAttrs],
) -> FormElement:
    """Represents a section containing interactive controls for submitting information.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form>
    """
    el = Element("form")(**attrs, **extra_attrs)(*children)
    return FormElement(el)


class FormAttrs(GlobalAttrs):
    """Attributes for the `<form>` element.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form>
    """

    accept_charset: NotRequired[str]
    """Space-separated character encodings the server accepts.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#accept-charset>
    """

    action: NotRequired[str]
    """The URL that processes the form submission.

    This value can be overridden by a `formaction` attribute on a `<button>`,
    `<input type="submit">`, or `<input type="image">` element. This attribute
    is ignored when `method="dialog"` is set.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#action>
    """

    enctype: NotRequired[
        Literal[
            "application/x-www-form-urlencoded",
            "multipart/form-data",
            "text/plain",
        ]
    ]
    """The encoding type.

    If the value of the method attribute is post, enctype is the MIME type of the form
    submission.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#enctype>
    """

    method: NotRequired[Literal["post", "get", "dialog"]]
    """The HTTP method to submit the form with.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#method>
    """

    name: NotRequired[str]
    """The name of the form.

    The value must not be the empty string, and must be unique among the `form` elements
    in the forms collection that it is in, if any.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#name>
    """

    novalidate: NotRequired[bool]
    """Indicates that the form shouldn't be validated when submitted.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#novalidate>
    """

    rel: NotRequired[str]
    """Controls the annotations and what kinds of links the form creates.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#rel>
    """

    target: NotRequired[str]
    """A keyword of the browsing context to display the linked resource.

    The following keywords have special meaning: `_self`, `_blank`, `_parent`, `_top`.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#target>
    """

==> haitch-0.10.2.tar.gz: haitch-0.10.2/src/haitch/_elements/_form.py <==
from __future__ import annotations

from typing import Literal, NewType, Optional

from typing_extensions import NotRequired, Unpack

from haitch._attrs import Attributes, GlobalAttrs
from haitch._elements._element import Element
from haitch._typing import Child

FormElement = NewType("FormElement", Element)
"""An `<form>` element."""


def form(
    *children: Child,
    extra_attrs: Optional[Attributes] = None,
    **attrs: Unpack[FormAttrs],
) -> FormElement:
    """Represents a section containing interactive controls for submitting information.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form>
    """
    el = Element("form")(**attrs, **extra_attrs or {})(*children)
    return FormElement(el)


class FormAttrs(GlobalAttrs):
    """Attributes for the `<form>` element.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form>
    """

    accept_charset: NotRequired[str]
    """Space-separated character encodings the server accepts.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#accept-charset>
    """

    action: NotRequired[str]
    """The URL that processes the form submission.

    This value can be overridden by a `formaction` attribute on a `<button>`,
    `<input type="submit">`, or `<input type="image">` element. This attribute
    is ignored when `method="dialog"` is set.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#action>
    """

    enctype: NotRequired[
        Literal[
            "application/x-www-form-urlencoded",
            "multipart/form-data",
            "text/plain",
        ]
    ]
    """The encoding type.

    If the value of the method attribute is post, enctype is the MIME type of the form
    submission.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#enctype>
    """

    method: NotRequired[Literal["post", "get", "dialog"]]
    """The HTTP method to submit the form with.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#method>
    """

    name: NotRequired[str]
    """The name of the form.

    The value must not be the empty string, and must be unique among the `form` elements
    in the forms collection that it is in, if any.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#name>
    """

    novalidate: NotRequired[bool]
    """Indicates that the form shouldn't be validated when submitted.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#novalidate>
    """

    rel: NotRequired[str]
    """Controls the annotations and what kinds of links the form creates.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#rel>
    """

    target: NotRequired[str]
    """A keyword of the browsing context to display the linked resource.

    The following keywords have special meaning: `_self`, `_blank`, `_parent`, `_top`.

    <https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form#target>
    """
